==> 1.0.75+1.tar.gz: lib/components/UikReview.dart <==
import 'package:flutter/material.dart';

import '../props/UikReviewProps.dart';
import 'UikWidget.dart';
import 'WidgetType.dart';

class UikReview extends UikWidget {
  WidgetType _widgetType;

  UikReviewProps _UikReviewProps;
  UikReview(this._widgetType, this._UikReviewProps)
      : super(_widgetType, _UikReviewProps);

  @override
  _UikReviewState createState() => _UikReviewState(_UikReviewProps);
}

class _UikReviewState extends State<UikReview> {
  UikReviewProps _UikReviewProps;
  _UikReviewState(this._UikReviewProps);

  @override
  Widget build(BuildContext context) {
    return Column(children: <Widget>[
      Container(
          child: Column(children: [
        Container(
          margin: EdgeInsets.all(10),
          child:
              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
            Container(child: _UikReviewProps.rating),
            Container(child: _UikReviewProps.datetext)
          ]),
        )
      ])),
      Container(
        margin: EdgeInsets.only(left: 10, right: 10),
        child: Row(children: [
          Container(child: _UikReviewProps.avatar),
          Container(
              margin: EdgeInsets.only(left: 5),
              child: _UikReviewProps.nametext),
        ]),
      ),
      Container(
        margin: EdgeInsets.only(left: 10, right: 10),
        child: Row(children: [Container(child: _UikReviewProps.dectext)]),
      ),
      Container(
        margin: EdgeInsets.only(top: 10, left: 10, right: 10),
        child: Row(children: [
          Container(
              margin: EdgeInsets.only(right: 10), child: _UikReviewProps.image),
          Container(
              margin: EdgeInsets.only(right: 10), child: _UikReviewProps.image),
          Container(
              margin: EdgeInsets.only(right: 10), child: _UikReviewProps.image),
        ]),
      ),
    ]);
  }
}

==> 1.0.111+1.tar.gz: lib/components/UikReview.dart <==
import 'package:flutter/material.dart';

import '../props/UikReviewProps.dart';
import 'UikWidget.dart';
import 'WidgetType.dart';

class UikReview extends UikWidget {
  WidgetType _widgetType;

  UikReviewProps _UikReviewProps;
  UikReview(this._widgetType, this._UikReviewProps)
      : super(_widgetType, _UikReviewProps);

  @override
  _UikReviewState createState() => _UikReviewState(_UikReviewProps);
}

class _UikReviewState extends State<UikReview> {
  UikReviewProps _UikReviewProps;
  _UikReviewState(this._UikReviewProps);

  @override
  Widget build(BuildContext context) {
    return Column(children: <Widget>[
      Container(
          child: Column(children: [
        Container(
          margin: EdgeInsets.all(10),
          child:
              Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: [
            Container(child: _UikReviewProps.rating),
            Container(child: _UikReviewProps.datetext)
          ]),
        )
      ])),
      Container(
        margin: EdgeInsets.only(left: 10, right: 10),
        child: Row(children: [
          Container(child: _UikReviewProps.avatar),
          Container(
              margin: EdgeInsets.only(left: 5),
              child: _UikReviewProps.nametext),
        ]),
      ),
      Container(
        margin: EdgeInsets.only(left: 10, right: 10),
        child: Row(children: [Container(child: _UikReviewProps.dectext)]),
      ),
      (_UikReviewProps.image != null)
          ? Container(
              margin: EdgeInsets.only(top: 10, left: 10, right: 10),
              child: Row(children: [
                Container(
                    margin: EdgeInsets.only(right: 10),
                    child: _UikReviewProps.image),
                Container(
                    margin: EdgeInsets.only(right: 10),
                    child: _UikReviewProps.image),
                Container(
                    margin: EdgeInsets.only(right: 10),
                    child: _UikReviewProps.image),
              ]),
            )
          : Text(""),
    ]);
  }
}
